<?php
/**
 * app/plugins/feedback/controllers/admin/feedback.php
 *
 * This is the feedback admin controller.
 *
 * @package TP Feedback
 * @version 3.0
 * @author  Joey Kimsey <Joey@thetempusproject.com>
 * @link    https://TheTempusProject.com
 * @license https://opensource.org/licenses/MIT [MIT LICENSE]
 */
namespace TheTempusProject\Controllers\Admin;

use TheTempusProject\Bedrock\Functions\Input;
use TheTempusProject\Houdini\Classes\Issues;
use TheTempusProject\Houdini\Classes\Views;
use TheTempusProject\Houdini\Classes\Navigation;
use TheTempusProject\Houdini\Classes\Components;
use TheTempusProject\Classes\AdminController;
use TheTempusProject\Models\Feedback as FeedbackModel;

class Feedback extends AdminController {
    protected static $feedback;

    public function __construct() {
        parent::__construct();
        self::$title = 'Admin - Feedback';
        self::$feedback = new FeedbackModel;
        $view = Navigation::activePageSelect( 'nav.admin', '/admin/feedback' );
        Components::set( 'ADMINNAV', $view );
    }

    public function view( $id = null ) {
        Views::view( 'feedback.admin.view', self::$feedback->findById( $id ) );
    }

    public function delete( $data = null ) {
        if ( Input::exists( 'submit' ) ) {
            $data = Input::post( 'F_' );
        }
        if ( self::$feedback->delete( (array) $data ) ) {
            Issues::add( 'success', 'feedback deleted' );
        } else {
            Issues::add( 'error', 'There was an error with your request.' );
        }
        $this->index();
    }

    public function clear( $data = null ) {
        self::$feedback->clear();
        $this->index();
    }

    public function index( $data = null ) {
        Views::view( 'feedback.admin.list', self::$feedback->list() );
    }
}
